import type { JanusVideoRoomOptions } from '../types';
/**
 * Interface with Janus Gateway Video Room and WebRTC-streamer API
 */
declare class JanusVideoRoom {
    private options;
    private readonly connection;
    /**
     * Instantiate object
     * @constructor
     * @param args
     */
    constructor(args?: Partial<JanusVideoRoomOptions>);
    /**
     * Ask to publish a stream from WebRTC-streamer in a Janus Video Room user
     * @param janusRoomId - id of the Janus Video Room to join
     * @param url - WebRTC stream to publish
     * @param name - name in Janus Video Room
     */
    join(janusRoomId: string, url: string, name: string): void;
    leave(janusRoomId: string, url: string, name: string): void;
    private handleHttpErrors;
    private emit;
    /**
     * Janus callback for Session Creation
     * @param dataJson
     * @param janusRoomId
     * @param url
     * @param name
     * @private
     */
    private onCreateSession;
    /**
     * Janus callback for Video Room Plugins Connection
     * @param dataJson
     * @param janusRoomId
     * @param url
     * @param name
     * @param sessionId
     * @private
     */
    private onPluginsAttached;
    /**
     * Janus callback for Video Room Joined
     * @param dataJson
     * @param janusRoomId
     * @param url
     * @param name
     * @param sessionId
     * @param pluginId
     * @private
     */
    private onJoinRoom;
    /**
     * Janus callback for Video Room Joined
     * @param dataJson
     * @param janusRoomId
     * @param url
     * @param name
     * @param sessionId
     * @param pluginId
     * @private
     */
    private onJoinRoomResult;
    /**
     * WebRTC streamer callback for Offer
     * @param dataJson
     * @param name
     * @param sessionId
     * @param pluginId
     * @param peerId
     * @private
     */
    private onCreateOffer;
    /**
     * Janus callback for WebRTC stream is published
     * @param dataJson
     * @param name
     * @param sessionId
     * @param pluginId
     * @param peerId
     * @private
     */
    private onPublishStream;
    /**
     * Janus callback for WebRTC stream is published
     * @param dataJson
     * @param name
     * @param sessionId
     * @param pluginId
     * @param peerId
     * @private
     */
    private onPublishStreamResult;
    /**
     * WebRTC streamer callback for Answer
     * @param dataJson
     * @param name
     * @param sessionId
     * @param pluginId
     * @param peerId
     * @private
     */
    private onSetAnswer;
    /**
     * WebRTC streamer callback for ICE candidate
     * @param dataJson
     * @param name
     * @param sessionId
     * @param pluginId
     */
    onReceiveCandidate(dataJson: any, name: string, sessionId: string, pluginId: string): void;
    /**
     * Janus callback for Long Polling
     * @param dataJson
     * @param name
     * @param sessionId
     * @private
     */
    private longPoll;
    /**
     * Janus callback for keepAlive Session
     * @param sessionId
     * @private
     */
    private keepAlive;
    /**
     * Janus callback for Error
     * @param status
     * @private
     */
    private onError;
}
export { JanusVideoRoom };
